import { ISODateTimeString } from "polar-shared/src/metadata/ISODateTimeStrings";
import { Duration, DurationMS, DurationStr } from "polar-shared/src/util/TimeDurations";
import { IDStr } from "polar-shared/src/util/Strings";
import { HighlightColor } from "polar-shared/src/metadata/IBaseHighlight";
export declare type ConfidenceInterval = number;
export declare type Answer = ConfidenceInterval;
export declare type LearningRating = 'again' | 'good' | 'easy';
export declare type ReviewRating = 'again' | 'hard' | 'good' | 'easy';
export declare type Rating = LearningRating | ReviewRating;
export declare type Difficulty = ConfidenceInterval;
export interface Schedule extends ReviewState {
    readonly nextReviewDate: ISODateTimeString;
}
export declare type DateLike = number | string | Date;
export declare type Days = number;
export interface BaseState {
    readonly reviewedAt: ISODateTimeString;
    readonly interval: Duration;
}
export interface LearningState extends BaseState {
    readonly intervals: ReadonlyArray<DurationStr>;
}
export interface ReviewState extends BaseState {
    readonly difficulty: Difficulty;
}
export interface LapsedState extends BaseState {
    readonly reviewState: ReviewState;
}
export declare type Stage = 'new' | 'learning' | 'review' | 'lapsed';
export declare type RepetitionMode = 'flashcard' | 'reading';
export interface ISpacedRep {
    readonly id: IDStr;
    readonly suspended?: boolean;
    readonly lapses?: number;
    readonly stage: Stage;
    readonly state: ReviewState | LearningState | LapsedState;
}
export declare type ItemType = 'flashcard' | 'reading';
export interface Task<A> {
    readonly id: IDStr;
    readonly action: A;
    readonly created: ISODateTimeString;
    readonly color?: HighlightColor;
    readonly mode: RepetitionMode;
}
export interface TaskRep<A> extends ISpacedRep, Task<A> {
    readonly age: DurationMS;
}
export interface MutableStageCounts {
    nrNew: number;
    nrLearning: number;
    nrReview: number;
    nrLapsed: number;
}
export interface StageCounts extends Readonly<MutableStageCounts> {
}
export declare class StageCountsCalculator {
    static createMutable(): MutableStageCounts;
    static calculate(tasks: ReadonlyArray<TaskRep<any>>): StageCounts;
}
